<?php

namespace SGalinski\SgMail\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Database\DatabaseConnection;
use TYPO3\CMS\Extbase\Persistence\Generic\Typo3QuerySettings;

/**
 * Repository for the Template object
 */
class TemplateRepository extends AbstractRepository {
	/**
	 * @param string $extensionKey
	 * @param string $templateName
	 * @param string $language
	 * @param int $pid
	 *
	 * @return Object
	 */
	public function findOneByTemplate($extensionKey, $templateName, $language, $pid = 0) {
		$query = $this->createQuery();

		$querySettings = $this->objectManager->get(Typo3QuerySettings::class);
		$querySettings->setRespectStoragePage(FALSE);

		$constraintsAnd[] = $query->equals('extension_key', $extensionKey);
		$constraintsAnd[] = $query->equals('template_name', $templateName);
		$constraintsAnd[] = $query->equals('language', $language);
		$constraintsAnd[] = $query->equals('pid', (int) $pid);

		$query->matching(
			$query->logicalAnd($constraintsAnd)
		);

		return $query->setLimit(1)->execute()->getFirst();
	}

	/**
	 * Delete a Template
	 *
	 * @param string $extensionKey
	 * @param string $templateName
	 * @param int $pid
	 */
	public function deleteTemplate($extensionKey, $templateName, $pid) {
		/** @var $databaseConnection DatabaseConnection */
		$databaseConnection = $GLOBALS['TYPO3_DB'];

		$tableName = 'tx_sgmail_domain_model_template';
		$where = 'extension_key = ' . $databaseConnection->fullQuoteStr($extensionKey, $tableName);
		$where .= ' AND template_name = ' . $databaseConnection->fullQuoteStr($templateName, $tableName);
		$where .= ' AND pid = ' . (int) $pid;

		$databaseConnection->exec_DELETEquery($tableName, $where);
	}
}
