<?php

namespace SGalinski\SgMail\ViewHelpers\Widget;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3Fluid\Fluid\Core\Rendering\RenderingContextInterface;

/**
 * Class UriViewHelper
 */
class UriViewHelper extends \TYPO3\CMS\Fluid\ViewHelpers\Widget\UriViewHelper {

	/**
	 * @var boolean
	 */
	protected $escapeOutput = FALSE;

	/**
	 * @var boolean
	 */
	protected $escapeChildren = FALSE;

	/**
	 * Get the URI for a non-AJAX Request.
	 *
	 * @param RenderingContextInterface $renderingContext
	 * @param array $arguments
	 * @return string the Widget URI
	 */
	protected static function getWidgetUri(RenderingContextInterface $renderingContext, array $arguments) {
		$controllerContext = $renderingContext->getControllerContext();
		$uriBuilder = $controllerContext->getUriBuilder();
		$argumentPrefix = $controllerContext->getRequest()->getArgumentPrefix();
		$parentNamespace = $controllerContext->getRequest()->getWidgetContext()->getParentPluginNamespace();
		$parentArguments = GeneralUtility::_GP($parentNamespace);
		$allArguments = [$argumentPrefix => $arguments];
		if ($parentArguments && isset($parentArguments['filters'])) {
			$allArguments[$parentNamespace . '[filters]'] = $parentArguments['filters'];
		}
		return $uriBuilder->reset()
			->setArguments($allArguments)
			->setSection($arguments['section'])
			->setAddQueryString(TRUE)
			->setAddQueryStringMethod($arguments['addQueryStringMethod'])
			->setArgumentsToBeExcludedFromQueryString([$argumentPrefix, 'cHash'])
			->setFormat($arguments['format'])
			->build();
	}
}
